@@ -93,7 +93,7 @@ if True:  # pragma: no cover
                     items = [[k, self[k]] for k in self]
                     inst_dict = vars(self).copy()
                     inst_dict.pop('_keys', None)
-                    return (self.__class__, (items,), inst_dict)
+                    return self.__class__, (items,), inst_dict
 
                 # Methods with indirect access via the above methods
                 setdefault = MutableMapping.setdefault
@@ -118,6 +118,27 @@ if True:  # pragma: no cover
                     return d
 
 
+class Comparable(object):
+    """Assumes child has self._comparable attr/@property"""
+    def __lt__(self, other):
+        return self._comparable < other._comparable
+
+    def __le__(self, other):
+        return (self < other) or (self == other)
+
+    def __eq__(self, other):
+        return self._comparable == other._comparable
+
+    def __ne__(self, other):
+        return not (self == other)
+
+    def __gt__(self, other):
+        return not (self <= other)
+
+    def __ge__(self, other):
+        return not (self < other)
+
+
 def _is_utf(encoding):
     try:
         u'\u2588\u2589'.encode(encoding)
@@ -160,13 +181,11 @@ def _environ_cols_windows(fp):  # pragma: no cover
         import struct
         from sys import stdin, stdout
 
-        io_handle = None
+        io_handle = -12  # assume stderr
         if fp == stdin:
             io_handle = -10
         elif fp == stdout:
             io_handle = -11
-        else:  # assume stderr
-            io_handle = -12
 
         h = windll.kernel32.GetStdHandle(io_handle)
         csbi = create_string_buffer(22)
@@ -181,8 +200,8 @@ def _environ_cols_windows(fp):  # pragma: no cover
     return None
 
 
-def _environ_cols_tput(*args):  # pragma: no cover
-    """ cygwin xterm (windows) """
+def _environ_cols_tput(*_):  # pragma: no cover
+    """cygwin xterm (windows)"""
     try:
         import shlex
         cols = int(subprocess.check_call(shlex.split('tput cols')))
@@ -206,11 +225,9 @@ def _environ_cols_linux(fp):  # pragma: no cover
             return array('h', ioctl(fp, TIOCGWINSZ, '\0' * 8))[1]
         except:
             try:
-                from os.environ import get
-            except ImportError:
+                return int(os.environ["COLUMNS"]) - 1
+            except KeyError:
                 return None
-            else:
-                return int(get('COLUMNS', 1)) - 1
 
 
 def _term_move_up():  # pragma: no cover
